/*
;Software License Agreement                                         
;                                                                    
;The software supplied herewith by Microchip Technology             
;Incorporated (the "Company") is intended and supplied to you, the  
;Companys customer, for use solely and exclusively on Microchip    
;products. The software is owned by the Company and/or its supplier,
;and is protected under applicable copyright laws. All rights are   
;reserved. Any use in violation of the foregoing restrictions may   
;subject the user to criminal sanctions under applicable laws, as   
;well as to civil liability for the breach of the terms and         
;conditions of this license.                                        
;                                                                    
;THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,  
;WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED  
;TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A       
;PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,  
;IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR         
;CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.       
;****************************************************************************
;PICkit(tm) 1 Tutorial #3
;Interrupts
;
;Filename:		ledint.c
;Author:		Mike Rylee
;Date:  		1.14.03
;Version:		1.00 (8 LED Version)
;Description:	This is a C written program designed to show the user
;				an interrupt driven LED State Machine.
;	       		Also, the program shows an interrupt on pin change to change the 
;				speed at which the leds are flashing.
;
;				This program uses the intlib.obj library file.  The library
;               contains the led display & push button debounce functions The
;               source code for the library can be found in the intlib.c file                       
;****************************************************************************
;Revision History
;
;****************************************************************************
;How To Flash LED's	
;****************************************************************************
;To Flash LED's simply write the 8-bit value into the variable ledregister
;in main()
;
;i.e.  ledregister = 0xFF  Flash 8 LED's D7-D0  (D7 is most significant bit)
;						                        (D0 is least significant bit)
;To Change The rate at which the LED's flash push button SW1
;****************************************************************************
*/

#include "ledint.h"

//***************************************************************************
//Main() - Main Routine
//***************************************************************************
void main()
{
	Init();                              //Initialize 12F629 Microcontroller
	while(1)                             //Loop Forever
	{	
		ledregister=0xFF;	             //Flash 8 LED's
	}
}

//***************************************************************************
//Init - Initialization Routine
//***************************************************************************
void Init()
{
	/* Comment out if using simulator, ICD2, or ICE2000
	#asm 								 //Load Factory Calibration Value Into OSCCAL
		call 0x3FF
		bsf	_STATUS,5					 				
		movwf _OSCCAL						
	#endasm
	*/
	InitLED();							 //Initialize LED variables
	ANSEL = 0;							 //12F675 Only
	TRISIO = 0xFF;                       //Set All I/O's As Inputs
	GPIO = CLEAR;                        //Clear GPIO
	VRCON = CLEAR;                       //Turn Off Voltage Reference Peripheral
	CMCON = 0x07;                        //Turn Off Comparator Peripheral
	TMR0 = CLEAR;                        //Clear Timer0
	OPTION = FASTFLASHING;               //Set Timer0 Prescaler To Fast Flash LED's
	IOCB3 = SET;                         //GP3 Interrupt On Pin Changed Enabled
	GPIE = SET;                          //Interrupt On Pin Change Enabled
	T0IE = SET;                          //Timer0 Overflow Interrupt Enabled
	T0IF = CLEAR;                        //Clear Timer0 Overflow Interrupt Flag
	GPIF = CLEAR;                        //Clear Interrupt On Pin Change Flag
	GIE = SET;                           //Enable All Interrupts
	return;
}

//***************************************************************************
//Functions
//***************************************************************************

//***************************************************************************
//Isr() - Interrupt Service Routine
//      - Timer0 Overflow & GP3 Pin Change Are Used
//***************************************************************************
void interrupt Isr()
{
	if ( (T0IE & T0IF) == SET)  	  //If A Timer0 Interrupt, Then
	{
		Display();					  //Update LED Array
		T0IF = CLEAR;                 //Clear Timer0 Interrupt Flag
	}
	
	else if ( (GPIE & GPIF) == SET)	  //If A GP3 Pin-Change Interrupt
	{
		if (Debounce() == TRUE)       //Debounce Pushbutton
			OPTION ^= SLOWFLASHING;   //If Pushbutton Status Is Closed, Then
			      					  //Toggle Timer0 Prescaler (Changes LED Flashing Speed)
		GPIF = CLEAR;                 //Clear Interrupt On Pin Change Flag
	}
	else if ( (INTE & INTF) == SET)   //If A GP2/INT External Intrrupt
	{
		
	}
	else if ( PEIE == SET)			  //If Peripheral Interrupts Enabled, Check Peripheral
	{                                 //Interrupts
	
		if ( (EEIE & EEIF) == SET)	  //If A EEPROM Interrupt
		{
			
		}
		else if ( (ADIE & ADIF) == SET) //If A A/D Converter Interrupt
		{
			
		}
		
		else if ( (CMIE & CMIF) == SET) //If A Comparator Interrupt
		{
			
		}
		else if ( (TMR1IE & TMR1IF) == SET) //If A Timer1 Interrupt
		{
			
		}
	}	
	return;
}
